You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:25:24 UTC

svn commit: r1591062 [2/15] - in /openoffice/trunk/main: registry/inc/registry/ registry/tools/ rhino/ ridljar/com/sun/star/lib/util/ ridljar/com/sun/star/uno/ rsc/inc/ rsc/source/parser/ rsc/source/rscpp/ sal/inc/osl/ sal/inc/rtl/ sal/inc/sal/ sal/inc...

Modified: openoffice/trunk/main/sal/inc/osl/process.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/osl/process.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/osl/process.h (original)
+++ openoffice/trunk/main/sal/inc/osl/process.h Tue Apr 29 19:25:03 2014
@@ -64,7 +64,7 @@ typedef	sal_uInt32 oslProcessExitCode;
 typedef enum {
     osl_Process_E_None,					/* no error */
     osl_Process_E_NotFound,				/* image not found */
-    osl_Process_E_TimedOut,				/* timout occured */
+    osl_Process_E_TimedOut,				/* timout occurred */
     osl_Process_E_NoPermission,	  	  	/* permission denied */
     osl_Process_E_Unknown,			  	/* unknown error */
     osl_Process_E_InvalidError,			/* unmapped error */
@@ -138,7 +138,7 @@ typedef void* oslProcess;
 	the process will be started in the context of the current user.
 	
 	@param ustrDirectory 
-	[in] The file URL of the working directory of the new proces. If the specified directory 
+	[in] The file URL of the working directory of the new process. If the specified directory 
 	does not exist or is inaccessible the working directory of the newly created process 
 	is undefined. If this parameter is NULL or the caller provides an empty string the 
 	new process will have the same current working directory as the calling process.
@@ -153,7 +153,7 @@ typedef void* oslProcess;
     [in] The number of environment variables to set.
     
 	@param pProcess
-	[out] Pointer to a oslProcess variable, wich receives the handle of the newly created process. 
+	[out] Pointer to a oslProcess variable, which receives the handle of the newly created process. 
 	This parameter must not be NULL.			
 
 	@return	
@@ -208,7 +208,7 @@ oslProcessError SAL_CALL osl_executeProc
 	the process will be started in the context of the current user.
 	
 	@param ustrDirectory 
-	[in] The file URL of the working directory of the new proces. If the specified directory 
+	[in] The file URL of the working directory of the new process. If the specified directory 
 	does not exist or is inaccessible the working directory of the newly created process 
 	is undefined. If this parameter is NULL or the caller provides an empty string the 
 	new process will have the same current working directory as the calling process.
@@ -223,7 +223,7 @@ oslProcessError SAL_CALL osl_executeProc
     [in] The number of environment variables to set.
     
 	@param pProcess
-	[out] Pointer to a oslProcess variable, wich receives the handle of the newly created process. 
+	[out] Pointer to a oslProcess variable, which receives the handle of the newly created process. 
 	This parameter must not be NULL.
 	
 	@param pChildInputWrite
@@ -318,7 +318,7 @@ oslProcessError SAL_CALL osl_joinProcess
     @return
     osl_Process_E_None on success
     osl_Process_E_TimedOut waiting for the child process timed out
-    osl_Process_E_Unknown an error occured or the parameter are invalid
+    osl_Process_E_Unknown an error occurred or the parameter are invalid
 
     @see osl_executeProcess
 */
@@ -378,13 +378,13 @@ oslProcessError SAL_CALL osl_getCommandA
 */
 void SAL_CALL osl_setCommandArgs (int argc, char **argv);
 
-/** Get the value of one enviroment variable.
+/** Get the value of one environment variable.
 	@param strVar [in] denotes the name of the variable to get.
 	@param strValue [out] string that receives the value of environment variable.
 */
 oslProcessError SAL_CALL osl_getEnvironment(rtl_uString *strVar, rtl_uString **strValue);
 
-/** Set the value of one enviroment variable.
+/** Set the value of one environment variable.
 	@param strVar [in] denotes the name of the variable to set.
 	@param strValue [in] string of the new value of environment variable.
 
@@ -392,7 +392,7 @@ oslProcessError SAL_CALL osl_getEnvironm
 */
 oslProcessError SAL_CALL osl_setEnvironment(rtl_uString *strVar, rtl_uString *strValue);
 
-/** Unsets the value of one enviroment variable.
+/** Unsets the value of one environment variable.
 	@param strVar [in] denotes the name of the variable to unset.
 
 	@since UDK 3.2.13

Modified: openoffice/trunk/main/sal/inc/osl/security.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/osl/security.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/osl/security.h (original)
+++ openoffice/trunk/main/sal/inc/osl/security.h Tue Apr 29 19:25:03 2014
@@ -74,7 +74,7 @@ oslSecurityError SAL_CALL osl_loginUser(
 	the maped drive on this server.
 	@param strUserName [in] denotes the name of the user to logg in.
 	@param strPasswd [in] the password for this user.
-	@param strFileServer [in] denotes the file server on wich the user is logged in.
+	@param strFileServer [in] denotes the file server on which the user is logged in.
 	@param pSecurity [out] returns the security handle if user could be logged in.
 	@return osl_Security_E_None if user could be logged in, otherwise an error-code.
 	@see osl_freeSecurityHandle

Modified: openoffice/trunk/main/sal/inc/osl/semaphor.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/osl/semaphor.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/osl/semaphor.h (original)
+++ openoffice/trunk/main/sal/inc/osl/semaphor.h Tue Apr 29 19:25:03 2014
@@ -39,7 +39,7 @@ typedef void* oslSemaphore;
 
 	@param InitialCount denotes the starting value the semaphore. If you set it to
 	zero, the first acquire() blocks. Otherwise InitialCount acquire()s  are
-	immedeatly  successfull.
+	immedeatly  successful.
 	@return 0 if the semaphore could not be created, otherwise a handle to the sem.
 */
 oslSemaphore SAL_CALL osl_createSemaphore(sal_uInt32 initialCount);

Modified: openoffice/trunk/main/sal/inc/osl/semaphor.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/osl/semaphor.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/osl/semaphor.hxx (original)
+++ openoffice/trunk/main/sal/inc/osl/semaphor.hxx Tue Apr 29 19:25:03 2014
@@ -43,7 +43,7 @@ namespace osl
 		/** Creates a semaphore.<BR>
 			@param InitialCount denotes the starting value the semaphore. If you set it to
 			zero, the first acquire() blocks. Otherwise InitialCount acquire()s  are
-			immedeatly  successfull.
+			immedeatly  successful.
 			@return 0 if the semaphore could not be created, otherwise a handle to the sem.
 		*/
 		

Modified: openoffice/trunk/main/sal/inc/osl/socket.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/osl/socket.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/osl/socket_decl.hxx (original)
+++ openoffice/trunk/main/sal/inc/osl/socket_decl.hxx Tue Apr 29 19:25:03 2014
@@ -272,7 +272,7 @@ namespace osl
 			You can specify a timeout-value in seconds/nanoseconds that denotes
 			how the operation will block if the Socket is not ready.
 			@return <code>sal_True</code> if read operations (recv, recvFrom, accept) on the Socket
-			will NOT block; <code>sal_False</code> if it would block or if an error occured.
+			will NOT block; <code>sal_False</code> if it would block or if an error occurred.
 			
 			@param pTimeout if 0, the operation will block without a timeout. Otherwise
 			the specified amout of time.
@@ -284,7 +284,7 @@ namespace osl
 			You can specify a timeout-value in seconds/nanoseconds that denotes
 			how the operation will block if the Socket is not ready.
 			@return <code>sal_True</code> if send operations (send, sendTo) on the Socket
-			will NOT block; <code>sal_False</code> if it would block or if an error occured.
+			will NOT block; <code>sal_False</code> if it would block or if an error occurred.
 			
 			@param pTimeout if 0, the operation will block without a timeout. Otherwise
 			the specified amout of time.
@@ -299,7 +299,7 @@ namespace osl
 			
 			@return <code>sal_True</code> if OOB-request operations (recv with appropriate flags) 
 			on the Socket will NOT block; <code>sal_False</code> if it would block or if
-			an error occured.
+			an error occurred.
 			
 			@param pTimeout if 0, the operation will block without a timeout. Otherwise
 			the specified amout of time.
@@ -315,7 +315,7 @@ namespace osl
 			<li> <code>osl_Socket_TypeRaw</code>
 			<li> <code>osl_Socket_TypeRdm</code>
 			<li> <code>osl_Socket_TypeSeqPacket</code>
-			<li> <code>osl_invalid_SocketType</code>, if an error occured
+			<li> <code>osl_invalid_SocketType</code>, if an error occurred
 			</ul>
 		*/
 		inline oslSocketType	SAL_CALL getType() const;
@@ -380,7 +380,7 @@ namespace osl
 
 			<li><code>osl_Socket_OptionTcpNoDelay</code><br>
 			  Disables the Nagle algorithm for send coalescing. (Do not
-			  collect data until a packet is full, instead send immediatly.
+			  collect data until a packet is full, instead send immediately.
 			  This increases network traffic but might improve latency-times.)
 			  1 = disables the algorithm, 0 = keeps it enabled. 
 			</ul>
@@ -399,7 +399,7 @@ namespace osl
 			<li><code>osl_Socket_LevelTcp</code>    : Level of Transmission Control Protocol
 			</ul>
 			@return The size of the attribute copied into pBuffer or -1 if an error
-			occured.
+			occurred.
 		*/
 		inline sal_Int32 SAL_CALL getOption(
 			oslSocketOption Option,
@@ -481,10 +481,10 @@ namespace osl
 		*/
 		inline void	SAL_CALL clearError() const;
 
-        /** returns a constant decribing the last error for the socket system.
+        /** returns a constant describing the last error for the socket system.
 			
-			@return osl_Socket_E_NONE if no error occured, invalid_SocketError if
-			an unknown (unmapped) error occured, otherwise an enum describing the
+			@return osl_Socket_E_NONE if no error occurred, invalid_SocketError if
+			an unknown (unmapped) error occurred, otherwise an enum describing the
 			error.
 			@see osl_getLastSocketError()
 		*/
@@ -574,7 +574,7 @@ namespace osl
 			<li><code>osl_Socket_MsgMaxIOVLen</code>
 			</ul>
 
-			@return the number of transfered bytes. It may be less than BytesToSend.
+			@return the number of transferred bytes. It may be less than BytesToSend.
 		*/
 		sal_Int32 SAL_CALL send(const void* pBuffer, 
 								sal_uInt32 BytesToSend, 
@@ -705,7 +705,7 @@ namespace osl
 			<li><code>osl_Socket_MsgMaxIOVLen</code>
 			</ul>
 			
-			@return the number of transfered bytes.
+			@return the number of transferred bytes.
 		*/
 		inline sal_Int32	SAL_CALL sendTo( const SocketAddr& ReceiverAddr, 
 											 const void* pBuffer,

Modified: openoffice/trunk/main/sal/inc/osl/thread.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/osl/thread.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/osl/thread.hxx (original)
+++ openoffice/trunk/main/sal/inc/osl/thread.hxx Tue Apr 29 19:25:03 2014
@@ -202,7 +202,7 @@ public:
     }
 
 	/** Set the data associated with the data key.
-		@returns True if operation was successfull
+		@returns True if operation was successful
 	*/
 	sal_Bool SAL_CALL setData(void *pData)
     {

Modified: openoffice/trunk/main/sal/inc/rtl/bootstrap.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/bootstrap.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/bootstrap.h (original)
+++ openoffice/trunk/main/sal/inc/rtl/bootstrap.h Tue Apr 29 19:25:03 2014
@@ -213,7 +213,7 @@ void SAL_CALL rtl_bootstrap_expandMacros
     an arbitrary, non-NULL value
 
     @param encoded
-    non-NULL out parameter, receiving the given value with all occurences of
+    non-NULL out parameter, receiving the given value with all occurrences of
     special characters ("$" and "\") escaped
 
     @since UDK 3.2.9

Modified: openoffice/trunk/main/sal/inc/rtl/bootstrap.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/bootstrap.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/bootstrap.hxx (original)
+++ openoffice/trunk/main/sal/inc/rtl/bootstrap.hxx Tue Apr 29 19:25:03 2014
@@ -145,7 +145,7 @@ namespace rtl
             an arbitrary value
 
             @return
-            the given value, with all occurences of special characters ("$" and
+            the given value, with all occurrences of special characters ("$" and
             "\") escaped
 
             @since UDK 3.2.9

Modified: openoffice/trunk/main/sal/inc/rtl/instance.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/instance.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/instance.hxx (original)
+++ openoffice/trunk/main/sal/inc/rtl/instance.hxx Tue Apr 29 19:25:03 2014
@@ -227,10 +227,10 @@ namespace {
     Some comments:
 
     For any instantiation of rtl_Instance, at most one call to a create method
-    may occur in the program code:  Each occurance of a create method within
+    may occur in the program code:  Each occurrence of a create method within
     the program code is supposed to return a fresh object instance on the
     first call, and that same object instance on subsequent calls; but
-    independent occurances of create methods are supposed to return
+    independent occurrences of create methods are supposed to return
     independent object instances.  Since there is a one-to-one correspondence
     between object instances and instantiations of rtl_Instance, the
     requirement should be clear.  One measure to enforce the requirement is
@@ -240,7 +240,7 @@ namespace {
     needs a funny "hand coded" prefix "rtl_" instead of a proper namespace
     prefix like "::rtl::".
 
-    A known problem with this template is when two occurences of calls to
+    A known problem with this template is when two occurrences of calls to
     create methods with identical template arguments appear in one translation
     unit.  Those two places will share a single object instance.  This can be
     avoided by using different Init structs (see the above code samples) in

Modified: openoffice/trunk/main/sal/inc/rtl/math.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/math.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/math.hxx (original)
+++ openoffice/trunk/main/sal/inc/rtl/math.hxx Tue Apr 29 19:25:03 2014
@@ -276,10 +276,10 @@ inline double approxAdd(double a, double
 	return a + b;
 }
 
-/** Substract two values (a-b).
+/** Subtract two values (a-b).
 
     If signs are identical and the values are equal according to approxEqual()
-    the method returns 0.0 instead of calculating the substraction.
+    the method returns 0.0 instead of calculating the subtraction.
  */
 inline double approxSub(double a, double b)
 {

Modified: openoffice/trunk/main/sal/inc/rtl/string.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/string.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/string.h (original)
+++ openoffice/trunk/main/sal/inc/rtl/string.h Tue Apr 29 19:25:03 2014
@@ -1056,7 +1056,7 @@ void SAL_CALL rtl_string_newTrim( rtl_St
     the number of the token to return, starting at index.
 
     @param cTok
-    the character that seperates the tokens.
+    the character that separates the tokens.
 
     @param index
     the position at which searching for the token starts.  Must not be greater

Modified: openoffice/trunk/main/sal/inc/rtl/string.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/string.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/string.hxx (original)
+++ openoffice/trunk/main/sal/inc/rtl/string.hxx Tue Apr 29 19:25:03 2014
@@ -726,7 +726,7 @@ public:
         while ( nIndex >= 0 );
 
       @param    token       the number of the token to return.
-      @param    cTok        the character which seperate the tokens.
+      @param    cTok        the character which separate the tokens.
       @param    index       the position at which the token is searched in the
                             string.
                             The index must not be greater thanthe length of the

Modified: openoffice/trunk/main/sal/inc/rtl/tencinfo.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/tencinfo.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/tencinfo.h (original)
+++ openoffice/trunk/main/sal/inc/rtl/tencinfo.h Tue Apr 29 19:25:03 2014
@@ -99,7 +99,7 @@ typedef struct _rtl_TextEncodingInfo
         ASCII control codes 0x00--1F are not included here, as they are used for
         special purposes in some encodings.
 
-        If an encoding has this property, it is easy to search for occurences of
+        If an encoding has this property, it is easy to search for occurrences of
         ASCII characters within strings of this encoding---you do not need to
         keep track whether a byte in the range 0x20--7F really represents an
         ASCII character or rather is part of some multi-byte character.

Modified: openoffice/trunk/main/sal/inc/rtl/tres.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/tres.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/tres.h (original)
+++ openoffice/trunk/main/sal/inc/rtl/tres.h Tue Apr 29 19:25:03 2014
@@ -53,7 +53,7 @@ typedef struct _rtl_TestResult rtl_TestR
 typedef void* rtl_funcstate;
 typedef void* rtl_cmpstate;
 
- /* type definitions of function pointers wich can be overloaded */
+ /* type definitions of function pointers which can be overloaded */
 typedef sal_Bool (SAL_CALL *rtl_tres_state_ptr)(
                                                 rtl_TestResult*,
                                                 sal_Bool,

Modified: openoffice/trunk/main/sal/inc/rtl/ustring.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/ustring.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/ustring.h (original)
+++ openoffice/trunk/main/sal/inc/rtl/ustring.h Tue Apr 29 19:25:03 2014
@@ -1418,7 +1418,7 @@ void SAL_CALL rtl_uString_newTrim( rtl_u
     the number of the token to return, starting at index.
 
     @param cTok
-    the character that seperates the tokens.
+    the character that separates the tokens.
 
     @param index
     the position at which searching for the token starts.  Must not be greater

Modified: openoffice/trunk/main/sal/inc/rtl/ustring.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/ustring.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/ustring.hxx (original)
+++ openoffice/trunk/main/sal/inc/rtl/ustring.hxx Tue Apr 29 19:25:03 2014
@@ -1095,7 +1095,7 @@ public:
         while ( nIndex >= 0 );
 
       @param    token       the number of the token to return
-      @param    cTok        the character which seperate the tokens.
+      @param    cTok        the character which separate the tokens.
       @param    index       the position at which the token is searched in the
                             string.
                             The index must not be greater than the length of the

Modified: openoffice/trunk/main/sal/inc/sal/main.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/sal/main.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/sal/main.h (original)
+++ openoffice/trunk/main/sal/inc/sal/main.h Tue Apr 29 19:25:03 2014
@@ -83,7 +83,7 @@ int SAL_CALL main(int argc, char ** argv
 #define INCLUDED_STDLIB_H
 #endif
 
-/* Sorry but this is neccessary cause HINSTANCE is a typedef that differs (C++ causes an error) */
+/* Sorry but this is necessary cause HINSTANCE is a typedef that differs (C++ causes an error) */
 
 #if 0
 

Modified: openoffice/trunk/main/sal/inc/systools/win32/StrConvert.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/systools/win32/StrConvert.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/systools/win32/StrConvert.h (original)
+++ openoffice/trunk/main/sal/inc/systools/win32/StrConvert.h Tue Apr 29 19:25:03 2014
@@ -72,7 +72,7 @@ if( wcStr ) \
    calculates the needed length of a corresponding the multi byte string
    list for a wide char string list.
 
-   @Param: cp - the code page to use for convertion.
+   @Param: cp - the code page to use for conversion.
            wcList - a double '\0' terminated wide char string list.
 */
 
@@ -82,7 +82,7 @@ int WideCharListGetMultiByteLength( UINT
    converts a double '\0' terminated list of wide char strings to a
    multi byte string list.
 
-   @Param: cp - the code page to use for convertion.
+   @Param: cp - the code page to use for conversion.
            wcList - a double '\0' terminated wide char string list.
            mbList - a double '\0' terminated multi byte string list.
            dwSize - size of buffer for multi byte string list.

Modified: openoffice/trunk/main/sal/osl/os2/file_path_helper.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/file_path_helper.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/file_path_helper.h (original)
+++ openoffice/trunk/main/sal/osl/os2/file_path_helper.h Tue Apr 29 19:25:03 2014
@@ -155,7 +155,7 @@
  
  /*****************************************
 	osl_systemPathGetParent
-	Replaces the last occurrance of a path
+	Replaces the last occurrence of a path
 	separator with '\0' and returns the 
 	position where the '/' was replaced
 	

Modified: openoffice/trunk/main/sal/osl/os2/file_path_helper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/file_path_helper.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/file_path_helper.hxx (original)
+++ openoffice/trunk/main/sal/osl/os2/file_path_helper.hxx Tue Apr 29 19:25:03 2014
@@ -162,7 +162,7 @@ namespace osl
  
  /*****************************************
 	systemPathGetParent
-	Replaces the last occurrance of a path
+	Replaces the last occurrence of a path
 	separator with '\0' and returns the 
 	position where the '/' was replaced
 	

Modified: openoffice/trunk/main/sal/osl/os2/file_url.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/file_url.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/file_url.cxx (original)
+++ openoffice/trunk/main/sal/osl/os2/file_url.cxx Tue Apr 29 19:25:03 2014
@@ -739,7 +739,7 @@ oslFileError SAL_CALL osl_getFileURLFrom
         /* adapt index to pTmp */
         nIndex += pTmp->length - ustrSystemPath->length;
         
-        /* remove all occurances of '//' */
+        /* remove all occurrences of '//' */
         for( nSrcIndex = nIndex + 1; nSrcIndex < pTmp->length; nSrcIndex++ )
         {
             if( ((sal_Unicode) '/' == pTmp->buffer[nSrcIndex]) && ((sal_Unicode) '/' == pTmp->buffer[nIndex]) )
@@ -913,7 +913,7 @@ oslFileError SAL_CALL osl_getSystemPathF
         {
             nOffset += nIndex;
 
-            /* break url down in '/' devided tokens tokens */
+            /* break url down in '/' divided tokens tokens */
             nIndex = rtl_ustr_indexOfChar_WithLength( ustrFileURL->buffer + nOffset, ustrFileURL->length - nOffset, (sal_Unicode) '/' );
             
             /* copy token to new string */

Modified: openoffice/trunk/main/sal/osl/os2/file_url.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/file_url.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/file_url.h (original)
+++ openoffice/trunk/main/sal/osl/os2/file_url.h Tue Apr 29 19:25:03 2014
@@ -23,7 +23,7 @@
  
  /***************************************************
   * Internal header file, declares all functions 
-  * that are not part of the offical API and are 
+  * that are not part of the official API and are 
   * not defined in the osl header files
   **************************************************/
  

Modified: openoffice/trunk/main/sal/osl/os2/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/makefile.mk?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/makefile.mk (original)
+++ openoffice/trunk/main/sal/osl/os2/makefile.mk Tue Apr 29 19:25:03 2014
@@ -38,7 +38,7 @@ MULTITHREAD_OBJ=TRUE
 .INCLUDE :  settings.mk
 
 # Uncomment the following line if you want to compile with -Wall 
-# it disables lots of unnecessary warnings comming from the Win32
+# it disables lots of unnecessary warnings coming from the Win32
 # header files (disabling warnings via command line only works with
 # MSVC >= 7.x)
 #

Modified: openoffice/trunk/main/sal/osl/os2/pipe.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/pipe.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/pipe.cxx (original)
+++ openoffice/trunk/main/sal/osl/os2/pipe.cxx Tue Apr 29 19:25:03 2014
@@ -468,7 +468,7 @@ oslPipeError SAL_CALL osl_getLastPipeErr
 
 sal_Int32 SAL_CALL osl_writePipe( oslPipe pPipe, const void *pBuffer , sal_Int32 n )
 {
-	/* loop until all desired bytes were send or an error occured */
+	/* loop until all desired bytes were send or an error occurred */
 	sal_Int32 BytesSend= 0;
 	sal_Int32 BytesToSend= n;
 
@@ -479,7 +479,7 @@ sal_Int32 SAL_CALL osl_writePipe( oslPip
 
 		RetVal= osl_sendPipe(pPipe, pBuffer, BytesToSend);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;
@@ -495,7 +495,7 @@ sal_Int32 SAL_CALL osl_writePipe( oslPip
 
 sal_Int32 SAL_CALL osl_readPipe( oslPipe pPipe, void *pBuffer , sal_Int32 n )
 {
-	/* loop until all desired bytes were read or an error occured */
+	/* loop until all desired bytes were read or an error occurred */
 	sal_Int32 BytesRead= 0;
 	sal_Int32 BytesToRead= n;
 
@@ -505,7 +505,7 @@ sal_Int32 SAL_CALL osl_readPipe( oslPipe
 		sal_Int32 RetVal;
 		RetVal= osl_receivePipe(pPipe, pBuffer, BytesToRead);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;

Modified: openoffice/trunk/main/sal/osl/os2/process.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/process.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/profile.c (original)
+++ openoffice/trunk/main/sal/osl/os2/profile.c Tue Apr 29 19:25:03 2014
@@ -1923,7 +1923,7 @@ static osl_TProfileImpl* acquireProfile(
 		
 			if ( pProfile->m_strFileName != 0  && pProfile->m_strFileName->buffer[0] != 0 )
 				FileURLToPath( pszFilename, PATH_MAX, pProfile->m_strFileName );
-		    /* hack: usualy you have a specific HAB, but NULL works here... */
+		    /* hack: usually you have a specific HAB, but NULL works here... */
 	        pProfile->m_hIni = PrfOpenProfile(NULL, (PCSZ)pszFilename);
 	        if (! pProfile->m_hIni)
 	        	return (NULL);
@@ -2124,7 +2124,7 @@ static sal_Bool lookupProfile(const sal_
 		if (osl_getExecutableFile(Path, sizeof(Path)) != osl_Process_E_None)
 			return (sal_False);
 
-		/* seperate path from filename */
+		/* separate path from filename */
 		if ((pChr = strrchr(Path, '\\')) == NULL)
 			if ((pChr = strrchr(Path, ':')) == NULL)
 				return (sal_False);

Modified: openoffice/trunk/main/sal/osl/os2/socket.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/socket.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/socket.c (original)
+++ openoffice/trunk/main/sal/osl/os2/socket.c Tue Apr 29 19:25:03 2014
@@ -782,7 +782,7 @@ oslSocketResult SAL_CALL osl_getAddrOfSo
 
 /** try to figure out a full-qualified hostname, by adding the current domain
     as given by the domainname program to the given hostname.
-	This function MUST NOT call gethostbyname since pHostName allready points
+	This function MUST NOT call gethostbyname since pHostName already points
 	to data returned by gethostname and would be garbled: use gethostname_r
 	instead!
  */
@@ -2492,7 +2492,7 @@ sal_Int32 SAL_CALL osl_readSocket (
 
 	OSL_ASSERT( pSocket);
 
-	/* loop until all desired bytes were read or an error occured */
+	/* loop until all desired bytes were read or an error occurred */
 	while (BytesToRead > 0)
 	{
 		sal_Int32 RetVal;
@@ -2501,7 +2501,7 @@ sal_Int32 SAL_CALL osl_readSocket (
 								   BytesToRead,
 								   osl_Socket_MsgNormal);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;
@@ -2521,7 +2521,7 @@ sal_Int32 SAL_CALL osl_readSocket (
 sal_Int32 SAL_CALL osl_writeSocket(
 	oslSocket pSocket, const void *pBuffer, sal_Int32 n )
 {
-	/* loop until all desired bytes were send or an error occured */
+	/* loop until all desired bytes were send or an error occurred */
 	sal_uInt32 BytesSend= 0;
 	sal_uInt32 BytesToSend= n;
 	sal_uInt8 *Ptr = ( sal_uInt8 * )pBuffer;
@@ -2534,7 +2534,7 @@ sal_Int32 SAL_CALL osl_writeSocket(
 
 		RetVal= osl_sendSocket( pSocket,Ptr,BytesToSend,osl_Socket_MsgNormal);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;

Modified: openoffice/trunk/main/sal/osl/os2/system.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/system.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/system.h (original)
+++ openoffice/trunk/main/sal/osl/os2/system.h Tue Apr 29 19:25:03 2014
@@ -362,7 +362,7 @@ char *macxp_tempnam( const char *tmpdir,
 #elif defined _BIG_ENDIAN_OO
 #	define _OSL_LITENDIAN
 #else
-#	error undetermined endianess
+#	error undetermined endianness
 #endif
 #else
 #if defined _LITTLE_ENDIAN
@@ -370,7 +370,7 @@ char *macxp_tempnam( const char *tmpdir,
 #elif defined _BIG_ENDIAN
 #	define _OSL_LITENDIAN
 #else
-#	error undetermined endianess
+#	error undetermined endianness
 #endif
 #endif
 

Modified: openoffice/trunk/main/sal/osl/unx/asm/interlck_sparc.s
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/unx/asm/interlck_sparc.s?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/unx/asm/interlck_sparc.s (original)
+++ openoffice/trunk/main/sal/osl/unx/asm/interlck_sparc.s Tue Apr 29 19:25:03 2014
@@ -38,7 +38,7 @@
  *    bv9 = 1   use sparcv9/sparcv8plus "cas" (no spinlock)
  *
  * 32 bit mode without v8 support (implies v8plus) or 64 bit mode:
- * No need (nor the possibilty) to call osl_InterlockedCountSetV9(), 
+ * No need (nor the possibility) to call osl_InterlockedCountSetV9(), 
  * sparcv9 mode is implied. Assemble with -xarch=v8plus (32 bit) or
  * -xarch=v9 (64 bit).
  * 

Modified: openoffice/trunk/main/sal/osl/unx/file_url.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/unx/file_url.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/unx/file_url.cxx (original)
+++ openoffice/trunk/main/sal/osl/unx/file_url.cxx Tue Apr 29 19:25:03 2014
@@ -188,7 +188,7 @@ oslFileError SAL_CALL osl_getSystemPathF
         {
             nOffset += nIndex;
 
-            /* break url down in '/' devided tokens tokens */
+            /* break url down in '/' divided tokens tokens */
             nIndex = rtl_ustr_indexOfChar_WithLength( ustrFileURL->buffer + nOffset, ustrFileURL->length - nOffset, (sal_Unicode) '/' );
             
             /* copy token to new string */
@@ -368,7 +368,7 @@ oslFileError SAL_CALL osl_getFileURLFrom
         /* adapt index to pTmp */
         nIndex += pTmp->length - ustrSystemPath->length;
         
-        /* remove all occurances of '//' */
+        /* remove all occurrences of '//' */
         for( nSrcIndex = nIndex + 1; nSrcIndex < pTmp->length; nSrcIndex++ )
         {
             if( ((sal_Unicode) '/' == pTmp->buffer[nSrcIndex]) && ((sal_Unicode) '/' == pTmp->buffer[nIndex]) )

Modified: openoffice/trunk/main/sal/osl/unx/pipe.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/unx/pipe.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/unx/pipe.c (original)
+++ openoffice/trunk/main/sal/osl/unx/pipe.c Tue Apr 29 19:25:03 2014
@@ -535,7 +535,7 @@ oslPipeError SAL_CALL osl_getLastPipeErr
 
 sal_Int32 SAL_CALL osl_writePipe( oslPipe pPipe, const void *pBuffer , sal_Int32 n )
 {
-	/* loop until all desired bytes were send or an error occured */
+	/* loop until all desired bytes were send or an error occurred */
 	sal_Int32 BytesSend= 0;
 	sal_Int32 BytesToSend= n;
 
@@ -546,7 +546,7 @@ sal_Int32 SAL_CALL osl_writePipe( oslPip
 
 		RetVal= osl_sendPipe(pPipe, pBuffer, BytesToSend);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;
@@ -562,7 +562,7 @@ sal_Int32 SAL_CALL osl_writePipe( oslPip
 
 sal_Int32 SAL_CALL osl_readPipe( oslPipe pPipe, void *pBuffer , sal_Int32 n )
 {
-	/* loop until all desired bytes were read or an error occured */
+	/* loop until all desired bytes were read or an error occurred */
 	sal_Int32 BytesRead= 0;
 	sal_Int32 BytesToRead= n;
 
@@ -572,7 +572,7 @@ sal_Int32 SAL_CALL osl_readPipe( oslPipe
 		sal_Int32 RetVal;
 		RetVal= osl_receivePipe(pPipe, pBuffer, BytesToRead);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;

Modified: openoffice/trunk/main/sal/osl/unx/process.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/unx/process.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/unx/process.c (original)
+++ openoffice/trunk/main/sal/osl/unx/process.c Tue Apr 29 19:25:03 2014
@@ -1445,7 +1445,7 @@ static int is_timeout(const struct timev
 }
 
 /**********************************************
- kill(pid, 0) is usefull for checking if a 
+ kill(pid, 0) is useful for checking if a 
  process is still alive, but remember that 
  kill even returns 0 if the process is already
  a zombie.

Modified: openoffice/trunk/main/sal/osl/unx/signal.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/unx/signal.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/unx/signal.c (original)
+++ openoffice/trunk/main/sal/osl/unx/signal.c Tue Apr 29 19:25:03 2014
@@ -130,7 +130,7 @@ plan to have the new handler use this si
 	{ SIGWINCH,  ACT_IGNORE, NULL },    /* window size change */
 	{ SIGURG,    ACT_EXIT,   NULL },    /* urgent socket condition */
 #ifdef SIGPOLL
-	{ SIGPOLL,   ACT_EXIT,   NULL },    /* pollable event occured */
+	{ SIGPOLL,   ACT_EXIT,   NULL },    /* pollable event occurred */
 #endif
 	{ SIGSTOP,   ACT_SYSTEM, NULL },    /* stop (cannot be caught or ignored) */
 	{ SIGTSTP,   ACT_SYSTEM, NULL },    /* user stop requested from tty */
@@ -252,7 +252,7 @@ static sal_Bool InitSignal()
 	/* Initialize the rest of the signals */
 	for (i = 0; i < NoSignals; i++) 
 	{
-		/* hack: stomcatd is attaching JavaVM wich dont work with an sigaction(SEGV) */
+		/* hack: stomcatd is attaching JavaVM which dont work with an sigaction(SEGV) */
 		if ((bSetSEGVHandler || Signals[i].Signal != SIGSEGV)
         && (bSetWINCHHandler || Signals[i].Signal != SIGWINCH)
 		&& (bSetILLHandler   || Signals[i].Signal != SIGILL))

Modified: openoffice/trunk/main/sal/osl/unx/socket.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/unx/socket.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/unx/socket.c (original)
+++ openoffice/trunk/main/sal/osl/unx/socket.c Tue Apr 29 19:25:03 2014
@@ -782,7 +782,7 @@ oslSocketResult SAL_CALL osl_getAddrOfSo
 
 /** try to figure out a full-qualified hostname, by adding the current domain
     as given by the domainname program to the given hostname.
-	This function MUST NOT call gethostbyname since pHostName allready points
+	This function MUST NOT call gethostbyname since pHostName already points
 	to data returned by gethostname and would be garbled: use gethostname_r
 	instead!
  */
@@ -2454,7 +2454,7 @@ sal_Int32 SAL_CALL osl_readSocket (
 
 	OSL_ASSERT( pSocket);
 
-	/* loop until all desired bytes were read or an error occured */
+	/* loop until all desired bytes were read or an error occurred */
 	while (BytesToRead > 0)
 	{
 		sal_Int32 RetVal;
@@ -2463,7 +2463,7 @@ sal_Int32 SAL_CALL osl_readSocket (
 								   BytesToRead,
 								   osl_Socket_MsgNormal);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;
@@ -2483,7 +2483,7 @@ sal_Int32 SAL_CALL osl_readSocket (
 sal_Int32 SAL_CALL osl_writeSocket(
 	oslSocket pSocket, const void *pBuffer, sal_Int32 n )
 {
-	/* loop until all desired bytes were send or an error occured */
+	/* loop until all desired bytes were send or an error occurred */
 	sal_uInt32 BytesSend= 0;
 	sal_uInt32 BytesToSend= n;
 	sal_uInt8 *Ptr = ( sal_uInt8 * )pBuffer;
@@ -2496,7 +2496,7 @@ sal_Int32 SAL_CALL osl_writeSocket(
 
 		RetVal= osl_sendSocket( pSocket,Ptr,BytesToSend,osl_Socket_MsgNormal);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;

Modified: openoffice/trunk/main/sal/osl/unx/system.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/unx/system.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/unx/system.h (original)
+++ openoffice/trunk/main/sal/osl/unx/system.h Tue Apr 29 19:25:03 2014
@@ -345,7 +345,7 @@ int macxp_resolveAlias(char *path, int b
 #elif defined _BIG_ENDIAN_OO
 #	define _OSL_LITENDIAN
 #else
-#	error undetermined endianess
+#	error undetermined endianness
 #endif
 #else
 #if defined _LITTLE_ENDIAN
@@ -353,7 +353,7 @@ int macxp_resolveAlias(char *path, int b
 #elif defined _BIG_ENDIAN
 #	define _OSL_LITENDIAN
 #else
-#	error undetermined endianess
+#	error undetermined endianness
 #endif
 #endif
 

Modified: openoffice/trunk/main/sal/osl/w32/MAKEFILE.MK
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/MAKEFILE.MK?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/MAKEFILE.MK (original)
+++ openoffice/trunk/main/sal/osl/w32/MAKEFILE.MK Tue Apr 29 19:25:03 2014
@@ -38,7 +38,7 @@ MULTITHREAD_OBJ=TRUE
 .INCLUDE :  settings.mk
 
 # Uncomment the following line if you want to compile with -Wall
-# it disables lots of unnecessary warnings comming from the Win32
+# it disables lots of unnecessary warnings coming from the Win32
 # header files (disabling warnings via command line only works with
 # MSVC >= 7.x)
 #

Modified: openoffice/trunk/main/sal/osl/w32/file_dirvol.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/file_dirvol.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/file_dirvol.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/file_dirvol.cxx Tue Apr 29 19:25:03 2014
@@ -515,7 +515,7 @@ static oslFileError osl_openLocalRoot(
         ZeroMemory( pDirImpl, sizeof(Directory_Impl) );
         rtl_uString_newFromString( &pDirImpl->m_pDirectoryPath, strSysPath );
 
-        /* Append backslash if neccessary */
+        /* Append backslash if necessary */
 
         /* @@@ToDo
            use function ensure backslash
@@ -580,7 +580,7 @@ static oslFileError SAL_CALL osl_openFil
     ZeroMemory( pDirImpl, sizeof(Directory_Impl) );
     rtl_uString_newFromString( &pDirImpl->m_pDirectoryPath, strDirectoryPath );
 
-	/* Append backslash if neccessary */
+	/* Append backslash if necessary */
 
 	/* @@@ToDo
 	   use function ensure backslash

Modified: openoffice/trunk/main/sal/osl/w32/file_url.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/file_url.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/file_url.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/file_url.cxx Tue Apr 29 19:25:03 2014
@@ -1004,7 +1004,7 @@ oslFileError SAL_CALL osl_searchFileURL(
 			LPCTSTR	lpszSearchFile = reinterpret_cast<LPCTSTR>(ustrSysPath->buffer);
 
 			/* Allocate space for buffer according to previous returned count of required chars */
-			/* +1 is not neccessary if we follow MSDN documentation but for robustness we do so */
+			/* +1 is not necessary if we follow MSDN documentation but for robustness we do so */
 			nBufferLength = dwResult + 1;
 			lpBuffer = lpBuffer ? 
 			    reinterpret_cast<LPTSTR>(rtl_reallocateMemory(lpBuffer, nBufferLength * sizeof(TCHAR))) : 

Modified: openoffice/trunk/main/sal/osl/w32/interlck.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/interlck.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/interlck.c (original)
+++ openoffice/trunk/main/sal/osl/w32/interlck.c Tue Apr 29 19:25:03 2014
@@ -33,7 +33,7 @@ extern int osl_isSingleCPU;
    Instead there is only returned a value greater than zero is the increment 
    result is greater than zero, but not the the result of the addition. 
    For Windows NT the native function could be used, because the correct result 
-   is returned. Beacuse of simpler code maintance and performace reasons we use
+   is returned. Because of simpler code maintenance and performace reasons we use
    on every x86-Windows-Platform the inline assembler implementation.
 */
  

Modified: openoffice/trunk/main/sal/osl/w32/module.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/module.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/module.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/module.cxx Tue Apr 29 19:25:03 2014
@@ -310,7 +310,7 @@ typedef BOOL (WINAPI *SymGetModuleInfo_P
     PIMAGEHLP_MODULE  ModuleInfo
     );
 
-/* Seems that IMAGEHLP.DLL is always availiable on NT 4. But MSDN from Platform SDK says Win 2K is required. MSDN from VS 6.0a says
+/* Seems that IMAGEHLP.DLL is always available on NT 4. But MSDN from Platform SDK says Win 2K is required. MSDN from VS 6.0a says
 	it's O.K on NT 4 ???!!! 
 	BTW: We are using ANSI function because not all version of IMAGEHLP.DLL contain Unicode support 
 */
@@ -421,7 +421,7 @@ typedef BOOL (WINAPI *GetModuleInformati
 
 #define bufsizeof(buffer) (sizeof(buffer) / sizeof((buffer)[0]))
 
-/* This version can fail because PSAPI.DLL is not always part of NT 4 despite MSDN Libary 6.0a say so */
+/* This version can fail because PSAPI.DLL is not always part of NT 4 despite MSDN Library 6.0a say so */
 
 static sal_Bool SAL_CALL _osl_addressGetModuleURL_NT( void *pv, rtl_uString **pustrURL )
 {

Modified: openoffice/trunk/main/sal/osl/w32/nlsupport.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/nlsupport.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/nlsupport.c (original)
+++ openoffice/trunk/main/sal/osl/w32/nlsupport.c Tue Apr 29 19:25:03 2014
@@ -75,7 +75,7 @@ BOOL CALLBACK EnumLocalesProcA( LPSTR lp
 	/* 
         get the ISO language code for this locale 
     
-        remeber: we call the GetLocaleInfoW function
+        remember: we call the GetLocaleInfoW function
         because the ansi version of this function returns
         an error under WinNT/2000 when called with an 
         unicode only lcid 

Modified: openoffice/trunk/main/sal/osl/w32/pipe.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/pipe.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/pipe.c (original)
+++ openoffice/trunk/main/sal/osl/w32/pipe.c Tue Apr 29 19:25:03 2014
@@ -561,7 +561,7 @@ sal_Int32 SAL_CALL osl_sendPipe(oslPipe 
 
 sal_Int32 SAL_CALL osl_writePipe( oslPipe pPipe, const void *pBuffer , sal_Int32 n )
 {
-	/* loop until all desired bytes were send or an error occured */
+	/* loop until all desired bytes were send or an error occurred */
 	sal_Int32 BytesSend= 0;
 	sal_Int32 BytesToSend= n;
 
@@ -572,7 +572,7 @@ sal_Int32 SAL_CALL osl_writePipe( oslPip
 
 		RetVal= osl_sendPipe(pPipe, pBuffer, BytesToSend);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;
@@ -588,7 +588,7 @@ sal_Int32 SAL_CALL osl_writePipe( oslPip
 
 sal_Int32 SAL_CALL osl_readPipe( oslPipe pPipe, void *pBuffer , sal_Int32 n )
 {
-	/* loop until all desired bytes were read or an error occured */
+	/* loop until all desired bytes were read or an error occurred */
 	sal_Int32 BytesRead= 0;
 	sal_Int32 BytesToRead= n;
 
@@ -598,7 +598,7 @@ sal_Int32 SAL_CALL osl_readPipe( oslPipe
 		sal_Int32 RetVal;
 		RetVal= osl_receivePipe(pPipe, pBuffer, BytesToRead);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;

Modified: openoffice/trunk/main/sal/osl/w32/process.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/process.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/process.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/process.cxx Tue Apr 29 19:25:03 2014
@@ -516,7 +516,7 @@ static sal_Bool ReadPipe(oslPipe hPipe,
                 sal_Int32* nBytes)
 {
         *nBytes = osl_receivePipe(hPipe, pBuffer, BytesToRead);
-        OSL_TRACE("tried to recieve %d, recieved %d.\n",
+        OSL_TRACE("tried to receive %d, received %d.\n",
                         BytesToRead, *nBytes);
         return (sal_Bool)((*nBytes >= 0) && (osl_getLastPipeError(hPipe) == osl_Pipe_E_None));
 }

Modified: openoffice/trunk/main/sal/osl/w32/procimpl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/procimpl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/procimpl.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/procimpl.cxx Tue Apr 29 19:25:03 2014
@@ -622,7 +622,7 @@ oslProcessError SAL_CALL osl_executeProc
 	    }
     }
     
-	/* if an error occured we have to close the server side pipe ends too */
+	/* if an error occurred we have to close the server side pipe ends too */
 
 	if (hInputWrite)
 		CloseHandle(hInputWrite);

Modified: openoffice/trunk/main/sal/osl/w32/profile.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/profile.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/profile.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/profile.cxx Tue Apr 29 19:25:03 2014
@@ -2497,7 +2497,7 @@ static sal_Bool lookupProfile(const sal_
 
 		rtl_uString_release(strTmp);
 
-		/* seperate path from filename */
+		/* separate path from filename */
 		if ((nPos = rtl_ustr_lastIndexOfChar(strExecutable->buffer, L'\\')) == -1)
 		{
 			if ((nPos = rtl_ustr_lastIndexOfChar(strExecutable->buffer, L':')) == -1)

Modified: openoffice/trunk/main/sal/osl/w32/security.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/security.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/security.c (original)
+++ openoffice/trunk/main/sal/osl/w32/security.c Tue Apr 29 19:25:03 2014
@@ -246,7 +246,7 @@ sal_Bool SAL_CALL osl_isAdministrator(os
 {
     if (Security != NULL)
 	{
-		/* ts: on Window 95 systems any user seems to be an adminstrator */
+		/* ts: on Window 95 systems any user seems to be an administrator */
 		if (!isWNT())
 		{
 			return(sal_True);

Modified: openoffice/trunk/main/sal/osl/w32/socket.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/socket.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/socket.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/socket.cxx Tue Apr 29 19:25:03 2014
@@ -1561,7 +1561,7 @@ sal_Int32 SAL_CALL osl_readSocket( oslSo
 
 	OSL_ASSERT( pSocket);
 
-	/* loop until all desired bytes were read or an error occured */
+	/* loop until all desired bytes were read or an error occurred */
 	sal_uInt32 BytesRead= 0;
 	sal_uInt32 BytesToRead= n;
 	while (BytesToRead > 0)
@@ -1572,7 +1572,7 @@ sal_Int32 SAL_CALL osl_readSocket( oslSo
 								   BytesToRead,
 								   osl_Socket_MsgNormal);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;
@@ -1593,7 +1593,7 @@ sal_Int32 SAL_CALL osl_writeSocket( oslS
 {
     OSL_ASSERT( pSocket );
 
-	/* loop until all desired bytes were send or an error occured */
+	/* loop until all desired bytes were send or an error occurred */
 	sal_uInt32 BytesSend= 0;
 	sal_uInt32 BytesToSend= n;
 	sal_uInt8 *Ptr = ( sal_uInt8 * )pBuffer;
@@ -1603,7 +1603,7 @@ sal_Int32 SAL_CALL osl_writeSocket( oslS
 
 		RetVal= osl_sendSocket( pSocket,Ptr,BytesToSend,osl_Socket_MsgNormal);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;

Modified: openoffice/trunk/main/sal/qa/buildall.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/buildall.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/buildall.pl (original)
+++ openoffice/trunk/main/sal/qa/buildall.pl Tue Apr 29 19:25:03 2014
@@ -154,7 +154,7 @@ sub initEnvironment()
           $g_sTempDir         = $ENV{TMP}  ? "$ENV{TMP}${FS}" : "${FS}tmp${FS}";
           last SWITCH;
       }
-      print STDERR "buildall.pl: unkown platform\n";
+      print STDERR "buildall.pl: unknown platform\n";
       exit(1);
   }
 }
@@ -266,7 +266,7 @@ sub giveOutFailures($$)
     if ($nFailures > 0)
     {
         # extra return for a better output
-        print "\nFailures occured: $nFailures\n";
+        print "\nFailures occurred: $nFailures\n";
         print "The whole output can be found in $sFailureFile\n";
         print "\n";
         
@@ -292,7 +292,7 @@ sub runASingleTest($$)
     my $sLogFile = $sLogPath . "/" . $sTarget . ".out";
 
     # due to the fact, a library name in one project is distinct, we should remember all already run through libraries and
-    # supress same libraries, if they occur one more.
+    # suppress same libraries, if they occur one more.
 
     if (exists $libraryRunThrough{getLibName($sTarget)})
     {
@@ -482,7 +482,7 @@ $/)
 
     if ($nGlobalFailures > 0)
     {
-        print "\nFailures over all occured: $nGlobalFailures\n";
+        print "\nFailures over all occurred: $nGlobalFailures\n";
         print "\nPASSED FAILED.\n";
     }
     else

Modified: openoffice/trunk/main/sal/qa/helper/gcov/deprecated.txt
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/helper/gcov/deprecated.txt?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/helper/gcov/deprecated.txt (original)
+++ openoffice/trunk/main/sal/qa/helper/gcov/deprecated.txt Tue Apr 29 19:25:03 2014
@@ -58,7 +58,7 @@
 
 # B. untested functions:
 #    functions need Client/Server model and blocking mode of transmission. some of the functions
-#    can not run through on testshl2 env while the same code can run successfully in normal seperate
+#    can not run through on testshl2 env while the same code can run successfully in normal separate
 #    files.
 #    1) in DatagramSocket class:
 #        osl_receiveFromSocket;
@@ -210,7 +210,7 @@
 
 # LLA:
 # marked as deprecated, due to the fact there is no access from outside
-# so this functions are not really accessable
+# so this functions are not really accessible
 # They are used in rtl/source/locale.c
         rtl_hashentry_destroy;
         rtl_hashfunc;

Modified: openoffice/trunk/main/sal/qa/osl/file/osl_File.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/file/osl_File.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/file/osl_File.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/file/osl_File.cxx Tue Apr 29 19:25:03 2014
@@ -347,7 +347,7 @@ inline sal_Bool isURL( const ::rtl::OUSt
 	return ( ( pathname.indexOf( aPreURL ) == 0 ) ? sal_True : sal_False );
 }
 
-/** concat two part to form a URL or system path, add PATH_SEPERATOR between them if necessary, add "file:///" to begining if necessary.
+/** concat two part to form a URL or system path, add PATH_SEPERATOR between them if necessary, add "file:///" to beginning if necessary.
 */
 inline void concatURL( ::rtl::OUString & pathname1, const ::rtl::OUString & pathname2 )
 {
@@ -588,7 +588,7 @@ inline sal_Bool ifFileExist( const ::rtl
 
 }
 
-//check if the file can be writen
+//check if the file can be written
 inline sal_Bool ifFileCanWrite( const ::rtl::OUString & str )
 {
 	sal_Bool		bCheckResult = sal_False;
@@ -1284,7 +1284,7 @@ namespace osl_FileBase
         the second only on windows based systems
         the first parameter are a file URL where we want to get the system path of,
         the second parameter is the assumed error of the osl_getSystemPathFromFileURL() function,
-        the thrid parameter is the assumed result string, the string will only test, if it's length is greater 0
+        the third parameter is the assumed result string, the string will only test, if it's length is greater 0
     */
 
     void SystemPath_FileURL::getSystemPathFromFileURL_001_1()
@@ -1461,7 +1461,7 @@ namespace osl_FileBase
 
 		}
 
-		//CJK charactors case
+		//CJK characters case
     void SystemPath_FileURL::getSystemPathFromFileURL_005( )
 		{
             ::rtl::OUString aUStr;
@@ -4497,7 +4497,7 @@ namespace osl_File
 			nError1 = testFile.close( );
 			CPPUNIT_ASSERT( ::osl::FileBase::E_None == nError1 );
 
-			CPPUNIT_ASSERT_MESSAGE( "test for read function: read from a special positon in the file",
+			CPPUNIT_ASSERT_MESSAGE( "test for read function: read from a special position in the file",
 				 					( 52 == nFilePointer ) && ( 26 == nCount_read ) && ( 0 == strncmp( buffer_read, &pBuffer_Char[26], 26 ) ) );
 		}
 
@@ -4546,7 +4546,7 @@ namespace osl_File
 			//get the current pointer;
  			nError1 = testFile.getPos( nFilePointer );
 			CPPUNIT_ASSERT( ::osl::FileBase::E_None == nError1 );
-			//reset pointer to the begining;
+			//reset pointer to the beginning;
  			nError1 = testFile.setPos( Pos_Absolut, 0 );
 			CPPUNIT_ASSERT( ::osl::FileBase::E_None == nError1 );
 			nError1 = testFile.read( buffer_read, 10, nCount_read );
@@ -6747,7 +6747,7 @@ inline void insertPID( ::rtl::OUString &
 
 /** to do some initialized work, we replace the NOADDITIONAL macro with the initialize work which
       will check the file and directory existence. and set some variables for test use.
-      to simplify the initialize work, we seperate it into UNIX section and Windows section, the main task
+      to simplify the initialize work, we separate it into UNIX section and Windows section, the main task
       of initialization is adapt all URL defined in osl_File_Const.h to TEMP/USERPID/URL style format,
       since there may be an instance that multiuser execute test at the same time, and the temp file
       may not be clean up in this case due to access right problem.
@@ -6808,7 +6808,7 @@ class GlobalObject
             }
 
             // LLA: t_print("after deleteTestDirectory\n");
-            //~ special clean up task in Windows and Unix seperately;
+            //~ special clean up task in Windows and Unix separately;
 #if ( defined UNX ) || ( defined OS2 )
             //~ some clean up task  for UNIX OS
             ;

Modified: openoffice/trunk/main/sal/qa/osl/module/osl_Module_Const.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/module/osl_Module_Const.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/module/osl_Module_Const.h (original)
+++ openoffice/trunk/main/sal/qa/osl/module/osl_Module_Const.h Tue Apr 29 19:25:03 2014
@@ -44,7 +44,7 @@
 
 #	define FILE_PREFIX          "file:///"
 
-//Korea charactors
+//Korea characters
 ::rtl::OUString aKname(
     RTL_CONSTASCII_STRINGPARAM(
         "/\xEC\x95\x88\xEB\x85\x95\xED\x95\x98\xEC\x84\xB8\xEC\x9A\x94"),

Modified: openoffice/trunk/main/sal/qa/osl/mutex/osl_Mutex.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/mutex/osl_Mutex.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/mutex/osl_Mutex.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/mutex/osl_Mutex.cxx Tue Apr 29 19:25:03 2014
@@ -500,7 +500,7 @@ namespace osl_Mutex
 			if ( bRes2 == sal_True )
 				aMutex.release( );
 	
-			CPPUNIT_ASSERT_MESSAGE( "release Mutex: try to aquire before and after the mutex has been released", 
+			CPPUNIT_ASSERT_MESSAGE( "release Mutex: try to acquire before and after the mutex has been released", 
 				bRes1 == sal_False && bRes2 == sal_True && bRunning == sal_True );
 	
 		}
@@ -514,7 +514,7 @@ namespace osl_Mutex
 			sal_Bool bRes1 = aMutex.release( );
 			sal_Bool bRes2 = aMutex.release( );
 		
-			CPPUNIT_ASSERT_MESSAGE( "release Mutex: mutex should not be released without aquire, should not release twice. although the behaviour is still under discussion, this test is passed on (LINUX), not passed on (SOLARIS)&(WINDOWS)", 
+			CPPUNIT_ASSERT_MESSAGE( "release Mutex: mutex should not be released without acquire, should not release twice. although the behaviour is still under discussion, this test is passed on (LINUX), not passed on (SOLARIS)&(WINDOWS)", 
 				bRes1 == sal_False && bRes2 == sal_False );
 #endif
 		}
@@ -655,7 +655,7 @@ namespace osl_Guard
 			aMutex.release( );
 			myThread.join( );
 	
-			CPPUNIT_ASSERT_MESSAGE("GuardThread constructor: reference initialization, aquire the mutex before running the thread, then check if it is blocking.", 
+			CPPUNIT_ASSERT_MESSAGE("GuardThread constructor: reference initialization, acquire the mutex before running the thread, then check if it is blocking.", 
 				bRes == sal_True);
 		}
 		
@@ -719,7 +719,7 @@ namespace osl_ClearableGuard
 			/// it will return sal_False if the aMutex has not been Guarded.
 			sal_Bool bRes = aMutex.release( );
 	
-			CPPUNIT_ASSERT_MESSAGE("ClearableMutexGuard constructor, test the aquire operation when initilized.", 
+			CPPUNIT_ASSERT_MESSAGE("ClearableMutexGuard constructor, test the acquire operation when initilized.", 
 				bRes == sal_True );
 		}
 	
@@ -733,7 +733,7 @@ namespace osl_ClearableGuard
 			/// it will return sal_False if the aMutex has not been Guarded.
 			sal_Bool bRes = aMutex.release( );
 	
-			CPPUNIT_ASSERT_MESSAGE("ClearableMutexGuard constructor, test the aquire operation when initilized, we use reference constructor this time.", 
+			CPPUNIT_ASSERT_MESSAGE("ClearableMutexGuard constructor, test the acquire operation when initilized, we use reference constructor this time.", 
 				bRes == sal_True );
 		}
 		
@@ -858,7 +858,7 @@ namespace osl_ResettableGuard
 			/// it will return sal_False if the aMutex has not been Guarded.
 			sal_Bool bRes = aMutex.release( );
 	
-			CPPUNIT_ASSERT_MESSAGE("ResettableMutexGuard constructor, test the aquire operation when initilized.", 
+			CPPUNIT_ASSERT_MESSAGE("ResettableMutexGuard constructor, test the acquire operation when initilized.", 
 				bRes == sal_True );
 		}
 	
@@ -872,7 +872,7 @@ namespace osl_ResettableGuard
 			/// it will return sal_False if the aMutex has not been Guarded.
 			sal_Bool bRes = aMutex.release( );
 	
-			CPPUNIT_ASSERT_MESSAGE( "ResettableMutexGuard constructor, test the aquire operation when initilized, we use reference constructor this time.", 
+			CPPUNIT_ASSERT_MESSAGE( "ResettableMutexGuard constructor, test the acquire operation when initilized, we use reference constructor this time.", 
 				bRes == sal_True );
 		}
 	
@@ -920,7 +920,7 @@ namespace osl_ResettableGuard
 			myMutexGuard.reset( );
 			sal_Bool bRes1 = aMutex.release( );
 			
-			CPPUNIT_ASSERT_MESSAGE( "ResettableMutexGuard method: reset, release after clear and reset, on Solaris, the mutex can be release without aquire, so it can not passed on (SOLARIS), but not the reason for reset_002", 
+			CPPUNIT_ASSERT_MESSAGE( "ResettableMutexGuard method: reset, release after clear and reset, on Solaris, the mutex can be release without acquire, so it can not passed on (SOLARIS), but not the reason for reset_002", 
 				( sal_False == bRes ) && ( sal_True == bRes1 ) );
 		}
 		

Modified: openoffice/trunk/main/sal/qa/osl/pipe/osl_Pipe.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/pipe/osl_Pipe.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/pipe/osl_Pipe.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/pipe/osl_Pipe.cxx Tue Apr 29 19:25:03 2014
@@ -239,7 +239,7 @@ namespace osl_Pipe
                 ///bRes1 = aNoAcquirePipe.is( );
 
 
-                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no aquire of handle, only validation test, do not know how to test no acquire.",
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no acquire of handle, only validation test, do not know how to test no acquire.",
                                         sal_True == bRes );
             }
 
@@ -254,7 +254,7 @@ namespace osl_Pipe
                 bRes = aAcquirePipe.is( );
                 bRes1 = aAcquirePipe1.is( );
 
-                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no aquire of handle.only validation test, do not know how to test no acquire.",
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no acquire of handle.only validation test, do not know how to test no acquire.",
                                         sal_True == bRes && sal_False == bRes1 );
             }
 
@@ -814,7 +814,7 @@ namespace osl_StreamPipe
                 aPipe.clear( );
                 // bRes1 = aNoAcquirePipe.is( );
 
-                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no aquire of handle, only validation test, do not know how to test no acquire.",
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no acquire of handle, only validation test, do not know how to test no acquire.",
                                         sal_True == bRes );
             }
 

Modified: openoffice/trunk/main/sal/qa/osl/process/osl_Thread.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/process/osl_Thread.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/process/osl_Thread.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/process/osl_Thread.cxx Tue Apr 29 19:25:03 2014
@@ -581,7 +581,7 @@ namespace osl_Thread
                 myThread* newthread = new myThread();
                 sal_Bool res1 = newthread->create();
                 sal_Bool res2 = newthread->create();
-                t_print("In non pro, an assertion should occured. This behaviour is right.\n");
+                t_print("In non pro, an assertion should occurred. This behaviour is right.\n");
                 termAndJoinThread(newthread);
                 delete newthread;
 

Modified: openoffice/trunk/main/sal/qa/osl/socket/osl_ConnectorSocket.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/socket/osl_ConnectorSocket.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/socket/osl_ConnectorSocket.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/socket/osl_ConnectorSocket.cxx Tue Apr 29 19:25:03 2014
@@ -205,7 +205,7 @@ namespace osl_ConnectorSocket
 				sal_True == compareSocketAddr( saPeerSocketAddr, saLocalSocketAddr  )  ) ;
 		}
 		// really an error or just delayed
-		// how to design senarios that will return osl_Socket_Interrupted, osl_Socket_TimedOut
+		// how to design scenarios that will return osl_Socket_Interrupted, osl_Socket_TimedOut
 		void connect_003()
 		{
 			::osl::SocketAddr saTargetSocketAddr1( rtl::OUString::createFromAscii("127.0.0.1"), IP_PORT_MYPORT3 );

Modified: openoffice/trunk/main/sal/qa/osl/socket/osl_Socket.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/socket/osl_Socket.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/socket/osl_Socket.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/socket/osl_Socket.cxx Tue Apr 29 19:25:03 2014
@@ -1511,7 +1511,7 @@ namespace osl_Socket
 			/// Socket constructor.
 			// ::osl::Socket sSocket;
 
-			CPPUNIT_ASSERT_MESSAGE( "test for ctors_none constructor function: check if the socket was created successfully, if no exception occured",
+			CPPUNIT_ASSERT_MESSAGE( "test for ctors_none constructor function: check if the socket was created successfully, if no exception occurred",
 									1 == 1 );
 		}
 
@@ -3060,7 +3060,7 @@ protected:
 			oslSocketResult eResult = asSocket.acceptConnection( ssConnectionSocket );
 			CPPUNIT_ASSERT_MESSAGE("shutdown_002: acceptConnection fail", eResult == osl_Socket_Ok );
 
-			/* set socket option SO_LINGER 0, so close immediatly */
+			/* set socket option SO_LINGER 0, so close immediately */
 			linger aLingerSet;
 		        sal_Int32 nBufferLen = sizeof( struct linger );
             		aLingerSet.l_onoff = 0;
@@ -3285,7 +3285,7 @@ namespace osl_ConnectorSocket
 				sal_True == compareSocketAddr( saPeerSocketAddr, saLocalSocketAddr  )  ) ;
 		}
 		// really an error or just delayed
-		// how to design senarios that will return osl_Socket_Interrupted, osl_Socket_TimedOut
+		// how to design scenarios that will return osl_Socket_Interrupted, osl_Socket_TimedOut
 		void connect_003()
 		{
 			::osl::SocketAddr saTargetSocketAddr1( aHostIp1, IP_PORT_MYPORT3 );

Modified: openoffice/trunk/main/sal/qa/osl/socket/osl_Socket2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/socket/osl_Socket2.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/socket/osl_Socket2.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/socket/osl_Socket2.cxx Tue Apr 29 19:25:03 2014
@@ -176,7 +176,7 @@ namespace osl_Socket
 			/// Socket constructor.
 			// ::osl::Socket sSocket();
 
-			CPPUNIT_ASSERT_MESSAGE( "test for ctors_none constructor function: check if the socket was created successfully, if no exception occured",
+			CPPUNIT_ASSERT_MESSAGE( "test for ctors_none constructor function: check if the socket was created successfully, if no exception occurred",
 									1 == 1 );
 		}
 

Modified: openoffice/trunk/main/sal/qa/osl/socket/osl_StreamSocket.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/socket/osl_StreamSocket.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/socket/osl_StreamSocket.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/socket/osl_StreamSocket.cxx Tue Apr 29 19:25:03 2014
@@ -819,7 +819,7 @@ namespace osl_StreamSocket
                 oslSocketResult eResult = asSocket.acceptConnection( ssConnectionSocket );
                 CPPUNIT_ASSERT_MESSAGE("shutdown_002: acceptConnection fail", eResult == osl_Socket_Ok );
 
-                /* set socket option SO_LINGER 0, so close immediatly */
+                /* set socket option SO_LINGER 0, so close immediately */
                 linger aLingerSet;
                 sal_Int32 nBufferLen = sizeof( struct linger );
                 aLingerSet.l_onoff = 0;
@@ -1037,7 +1037,7 @@ namespace osl_StreamSocket
                     {
                         t_print("read()\n");
                         m_nReadCount = aSocket.read( m_pBuffer, m_nBufferSize );
-                        t_print("%d bytes recived.\n", m_nReadCount);
+                        t_print("%d bytes received.\n", m_nReadCount);
                     }
                 }
                 else
@@ -1108,12 +1108,12 @@ namespace osl_StreamSocket
 
                 if (! aSocketAddr.setPort(IP_PORT_TEST))
                 {
-                    t_print("# cant set port\n" );
+                    t_print("# can't set port\n" );
                 }
 
                 if (! aSocketAddr.setHostname(rtl::OUString::createFromAscii(_sAddr.getStr())))
                 {
-                    t_print("# cant set hostname/ip\n" );
+                    t_print("# can't set hostname/ip\n" );
                 }
 
                 rtl::OUString aHostname = aSocketAddr.getHostname();

Modified: openoffice/trunk/main/sal/qa/osl/socket/sockethelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/socket/sockethelper.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/socket/sockethelper.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/socket/sockethelper.cxx Tue Apr 29 19:25:03 2014
@@ -283,7 +283,7 @@ sal_Bool ifIpv4is( const ::rtl::ByteSequ
 	return sal_False;
 }
 
-/** if the IP or hostname is availble( alive )
+/** if the IP or hostname is available( alive )
 */
 /*sal_Bool ifAvailable( const char *  stringAddrOrHostName )
 {

Modified: openoffice/trunk/main/sal/qa/osl/socket/sockethelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/socket/sockethelper.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/socket/sockethelper.hxx (original)
+++ openoffice/trunk/main/sal/qa/osl/socket/sockethelper.hxx Tue Apr 29 19:25:03 2014
@@ -143,7 +143,7 @@ void printSocketResult( oslSocketResult 
 /** if 4 parts of an IP addr are equal to specified values
 */
 sal_Bool ifIpv4is( const ::rtl::ByteSequence Ipaddr, sal_Int8 seq1, sal_Int8 seq2, sal_Int8 seq3, sal_Int8 seq4 );
-/** if the IP or hostname is  availble( alive )
+/** if the IP or hostname is  available( alive )
 */
 //sal_Bool ifAvailable( const char *  stringAddrOrHostName );
 sal_Bool ifAvailable( rtl::OUString const&  strAddrOrHostName );

Modified: openoffice/trunk/main/sal/qa/rtl/bootstrap/rtl_Bootstrap.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/rtl/bootstrap/rtl_Bootstrap.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/rtl/bootstrap/rtl_Bootstrap.cxx (original)
+++ openoffice/trunk/main/sal/qa/rtl/bootstrap/rtl_Bootstrap.cxx Tue Apr 29 19:25:03 2014
@@ -191,7 +191,7 @@ namespace rtl_Bootstrap
                 //              but try to use ${file::KEYVALUE} than 'file' will only used out of the 'executable path'/file
                 //              not from the path given from the absolute path.
 
-                // Due to the fact, we create at this position a file (createTestshl2rc() ), we check for existance
+                // Due to the fact, we create at this position a file (createTestshl2rc() ), we check for existence
                 bool bFileExist = t_fileExist( suGetname );
                 CPPUNIT_ASSERT_MESSAGE("ctor error with initial file.", bFileExist == true );
             }

Modified: openoffice/trunk/main/sal/qa/rtl_strings/rtl_OUString.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/rtl_strings/rtl_OUString.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/rtl_strings/rtl_OUString.cxx (original)
+++ openoffice/trunk/main/sal/qa/rtl_strings/rtl_OUString.cxx Tue Apr 29 19:25:03 2014
@@ -744,7 +744,7 @@ extern "C" void /* sal_Bool */ SAL_CALL 
 		{"null and Ustr1", new OUString, new OUString(aUStr1)},
 		{"Ustr2 and Ustr1", new OUString(aUStr2), 
          new OUString(aUStr1)},
-		{""" and Ustr1 from bit charactor buffer",  
+		{""" and Ustr1 from bit character buffer",  
          new OUString(aUStr1),
          new OUString( "",
                        0,

Modified: openoffice/trunk/main/sal/rtl/source/unload.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/rtl/source/unload.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/rtl/source/unload.cxx (original)
+++ openoffice/trunk/main/sal/rtl/source/unload.cxx Tue Apr 29 19:25:03 2014
@@ -330,7 +330,7 @@ static ListenerMap& getListenerMap()
 // This queue contains cookies which have been passed out by rtl_addUnloadingListener and 
 // which have been regainded by rtl_removeUnloadingListener. When rtl_addUnloadingListener
 // is called then a cookie has to be returned. First we look into the set if there is one 
-// availabe. Otherwise a new cookie will be provided.
+// available. Otherwise a new cookie will be provided.
 // not a new value is returned.
 
 typedef std::deque<

Modified: openoffice/trunk/main/sal/systools/win32/kill/kill.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/systools/win32/kill/kill.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/systools/win32/kill/kill.cxx (original)
+++ openoffice/trunk/main/sal/systools/win32/kill/kill.cxx Tue Apr 29 19:25:03 2014
@@ -67,7 +67,7 @@ static inline bool IsValidHandle( HANDLE
 #define elementsof( a ) (sizeof(a) / sizeof( (a)[0] ))
 
 /////////////////////////////////////////////////////////////////////////////
-// Retrieves function adress in another process
+// Retrieves function address in another process
 /////////////////////////////////////////////////////////////////////////////
 
 #if 1

Modified: openoffice/trunk/main/sal/systools/win32/uwinapi/MoveFileExA.cpp
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/systools/win32/uwinapi/MoveFileExA.cpp?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/systools/win32/uwinapi/MoveFileExA.cpp (original)
+++ openoffice/trunk/main/sal/systools/win32/uwinapi/MoveFileExA.cpp Tue Apr 29 19:25:03 2014
@@ -76,7 +76,7 @@ IMPLEMENT_THUNK( kernel32, WINDOWS, BOOL
 
 			fSuccess = CopyFileA( lpExistingFileNameA, lpNewFileNameA, bFailIfExist );
 
-			// In case of successfull copy do not return FALSE if delete fails.
+			// In case of successful copy do not return FALSE if delete fails.
 			// Error detection is done by GetLastError()
 
 			if ( fSuccess )

Modified: openoffice/trunk/main/sal/test/bootstrap
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/test/bootstrap?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/test/bootstrap (original)
+++ openoffice/trunk/main/sal/test/bootstrap Tue Apr 29 19:25:03 2014
@@ -72,7 +72,7 @@ echo 13
 ./testbootstrap TheKeysValue -env:ININAME=./bootstraptest.ini \
 	-env:'MYBOOTSTRAPTESTVALUE=${$ININAME:${$ININAME:SecondSection:IndirectSection}:${$ININAME:SecondSection:IndirectKey}}'
 
-# test no infinit recursion
+# test no infinite recursion
 echo 14
 ./testbootstrap "***RECURSION DETECTED***" -env:'MYBOOTSTRAPTESTVALUE=$MYBOOTSTRAPTESTVALUE'
 

Modified: openoffice/trunk/main/sal/test/bootstrap.bat
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/test/bootstrap.bat?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/test/bootstrap.bat (original)
+++ openoffice/trunk/main/sal/test/bootstrap.bat Tue Apr 29 19:25:03 2014
@@ -70,7 +70,7 @@ rem ini access with complex macro expans
 echo 13
 .\testbootstrap TheKeysValue -env:ININAME=./bootstraptest.ini -env:MYBOOTSTRAPTESTVALUE=${$ININAME:${$ININAME:SecondSection:IndirectSection}:${$ININAME:SecondSection:IndirectKey}}
 
-rem test no infinit recursion
+rem test no infinite recursion
 echo 14
 .\testbootstrap "***RECURSION DETECTED***" -env:MYBOOTSTRAPTESTVALUE=$MYBOOTSTRAPTESTVALUE
 

Modified: openoffice/trunk/main/sal/test/bootstrap.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/test/bootstrap.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/osl/socket.h (original)
+++ openoffice/trunk/main/sal/inc/osl/socket.h Tue Apr 29 19:25:03 2014
@@ -190,7 +190,7 @@ typedef enum {
  */
 typedef enum {
     osl_Socket_Ok,          /* successful completion */
-    osl_Socket_Error,       /* error occured, check osl_getLastSocketError() for details */
+    osl_Socket_Error,       /* error occurred, check osl_getLastSocketError() for details */
 	osl_Socket_TimedOut,    /* blocking operation timed out */
     osl_Socket_Interrupted, /* blocking operation was interrupted */
     osl_Socket_InProgress,	/* nonblocking operation is in progress */
@@ -545,7 +545,7 @@ sal_Int32 SAL_CALL osl_receiveFromSocket
 	<li><code>osl_Socket_MsgMaxIOVLen</code>
 	</ul>
 
-	@return the number of transfered bytes.
+	@return the number of transferred bytes.
 */
 sal_Int32 SAL_CALL osl_sendSocket(oslSocket Socket,
 	    			   const void* pBuffer,
@@ -575,7 +575,7 @@ sal_Int32 SAL_CALL osl_sendSocket(oslSoc
 	<li><code>osl_Socket_MsgMaxIOVLen</code>
 	</ul>
 
-	@return the number of transfered bytes.
+	@return the number of transferred bytes.
 */
 sal_Int32 SAL_CALL osl_sendToSocket(oslSocket Socket,
 	    				 oslSocketAddr ReceiverAddr,
@@ -589,7 +589,7 @@ sal_Int32 SAL_CALL osl_sendToSocket(oslS
 	how long the operation will block if the Socket is not ready.
 
 	@return <code>sal_True</code> if read operations (recv, recvFrom, accept) on the Socket
-	will NOT block; <code>sal_False</code> if it would block or if an error occured.
+	will NOT block; <code>sal_False</code> if it would block or if an error occurred.
 	
 	@param Socket the Socket to perfom the operation on.
 	@param pTimeout if NULL, the operation will block without a timeout. 
@@ -600,7 +600,7 @@ sal_Bool SAL_CALL osl_isReceiveReady(osl
 	You can specify a timeout-value in seconds/microseconds that denotes
 	how long the operation will block if the Socket is not ready.
 	@return <code>sal_True</code> if send operations (send, sendTo) on the Socket
-	will NOT block; <code>sal_False</code> if it would block or if an error occured.
+	will NOT block; <code>sal_False</code> if it would block or if an error occurred.
 	
 	@param Socket the Socket to perfom the operation on.
 	@param pTimeout if NULL, the operation will block without a timeout. Otherwise
@@ -612,7 +612,7 @@ sal_Bool SAL_CALL osl_isSendReady(oslSoc
 	You can specify a timeout-value in seconds/microseconds that denotes
 	how long the operation will block if the Socket has no pending OOB data.
 	@return <code>sal_True</code> if OOB-request operations (recv with appropriate flags)
-	on the Socket will NOT block; <code>sal_False</code> if it would block or if an error occured.
+	on the Socket will NOT block; <code>sal_False</code> if it would block or if an error occurred.
 	
 	@param Socket the Socket to perfom the operation on.
 	@param pTimeout if NULL, the operation will block without a timeout. 
@@ -700,7 +700,7 @@ sal_Bool SAL_CALL osl_shutdownSocket(osl
 
 	<li><code>osl_Socket_OptionTcpNoDelay</code><br>
 	Disables the Nagle algorithm for send coalescing. (Do not
-	collect data until a packet is full, instead send immediatly.
+	collect data until a packet is full, instead send immediately.
 	This increases network traffic but might improve latency-times.)
 	1 = disables the algorithm, 0 = keeps it enabled. 
 	</ul>
@@ -712,7 +712,7 @@ sal_Bool SAL_CALL osl_shutdownSocket(osl
 
 	@param BufferSize contains the length of the Buffer.
 
-	@return -1 if an error occured or else the size of the data copied into
+	@return -1 if an error occurred or else the size of the data copied into
 	pBuffer.
 	@see osl_setSocketOption()
 */
@@ -773,7 +773,7 @@ sal_Bool SAL_CALL osl_isNonBlockingMode(
 	<li> osl_Socket_TypeRaw
 	<li> osl_Socket_TypeRdm
 	<li> osl_Socket_TypeSeqPacket
-	<li> osl_invalid_SocketType, if an error occured
+	<li> osl_invalid_SocketType, if an error occurred
 	</ul>
 	
 */
@@ -784,10 +784,10 @@ oslSocketType SAL_CALL osl_getSocketType
 */
 void SAL_CALL osl_getLastSocketErrorDescription(oslSocket Socket, rtl_uString **strError);
 
-/** returns a constant decribing the last error for the socket system.
-	@return <code>osl_Socket_E_NONE</code> if no error occured,
+/** returns a constant describing the last error for the socket system.
+	@return <code>osl_Socket_E_NONE</code> if no error occurred,
 	        <code>osl_invalid_SocketError</code> if	an unknown (unmapped)
-			error occured, otherwise an enum describing the	error.
+			error occurred, otherwise an enum describing the	error.
 */
 oslSocketError SAL_CALL osl_getLastSocketError(oslSocket Socket);
 

Modified: openoffice/trunk/main/sal/inc/osl/socket_decl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/osl/socket_decl.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/os2/process.c (original)
+++ openoffice/trunk/main/sal/osl/os2/process.c Tue Apr 29 19:25:03 2014
@@ -464,11 +464,11 @@ oslProcessError SAL_CALL osl_psz_execute
 
 		OSL_TRACE( "osl_executeProcess with DosExecPgm (args: %s)\n", args );
 
-		/* calculate needed space for environment: since enviroment var search
-		   is a linear scan of the current enviroment, we place new variables
+		/* calculate needed space for environment: since environment var search
+		   is a linear scan of the current environment, we place new variables
 		   before existing ones; so the child will find new definitions before
 		   olders; this doesn't require us to replace existing vars */
 		// existing enviroment size
 		n = 0;
 		p = environ;
 		while( *p) 
@@ -848,7 +848,7 @@ oslProcessError SAL_CALL osl_getCommandA
         {
             /*
              *  C-Runtime expects char to be unsigned and so to be
-             *  preceeded with 00 instead of FF when converting to int
+             *  preceded with 00 instead of FF when converting to int
              */
             int n = *((unsigned char *) pszCmdLine);
 			if (! (isspace(n) || (*pszCmdLine == '\0')) )
@@ -464,11 +464,11 @@ oslProcessError SAL_CALL osl_psz_execute
 		   before existing ones; so the child will find new definitions before
 		   olders; this doesn't require us to replace existing vars */
-		// existing enviroment size
+		// existing environment size
 		n = 0;
 		p = environ;

Modified: openoffice/trunk/main/sal/osl/os2/profile.c
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/os2/profile.c?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/test/bootstrap.pl (original)
+++ openoffice/trunk/main/sal/test/bootstrap.pl Tue Apr 29 19:25:03 2014
@@ -217,7 +217,7 @@ if (!$rc) {
 	$state = 0;
 }
 
 # test no infinit recursion
 if ($ENV{GUI} eq "WNT") {
 	$rc = system "./testbootstrap", 
 	'"***RECURSION DETECTED***"', 
@@ -229,7 +229,7 @@ else {
 	'-env:MYBOOTSTRAPTESTVALUE=$MYBOOTSTRAPTESTVALUE';
 }
 if (!$rc) {
-	$comment = $comment . "no infinit recursion test not passed\n";
+	$comment = $comment . "no infinite recursion test not passed\n";
 	$state = 0;
 }
 
@@ -217,7 +217,7 @@ if (!$rc) {
 }
 
-# test no infinit recursion
+# test no infinite recursion
 if ($ENV{GUI} eq "WNT") {
 	$rc = system "./testbootstrap", 

Modified: openoffice/trunk/main/sal/textenc/generate/cns116431992.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/textenc/generate/cns116431992.pl?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sal/textenc/generate/cns116431992.pl (original)
+++ openoffice/trunk/main/sal/textenc/generate/cns116431992.pl Tue Apr 29 19:25:03 2014
@@ -322,7 +322,7 @@ for ($cns_plane = 1; $cns_plane <= 16; +
                         $cns1_row = ($cns1 >> 8) & 0xFF;
                         $cns1_column = $cns1 & 0xFF;
 
                         # Do not map from Unicode to Fictious Character Set
                         # Extensions (Lunde, p. 131), if possible:
                         if ($cns_plane == 3
                             && ($cns_row == 66 && $cns_column > 38
@@ -330,7 +330,7 @@ for ($cns_plane = 1; $cns_plane <= 16; +
                         {
                             print " (",
                                   printUtf32($utf32),
-                                  " to fictious ",
+                                  " to fictitious ",
                                   printCns116431992($cns_plane,
                                                     $cns_row,
                                                     $cns_column),
@@ -350,7 +350,7 @@ for ($cns_plane = 1; $cns_plane <= 16; +
                                        | $cns_column;
                             print " (",
                                   printUtf32($utf32),
-                                  " to fictious ",
+                                  " to fictitious ",
                                   printCns116431992($cns1_plane,
                                                     $cns1_row,
                                                     $cns1_column),
@@ -322,7 +322,7 @@ for ($cns_plane = 1; $cns_plane <= 16; +
                         $cns1_column = $cns1 & 0xFF;
 
-                        # Do not map from Unicode to Fictious Character Set
+                        # Do not map from Unicode to Fictitious Character Set
                         # Extensions (Lunde, p. 131), if possible:
                         if ($cns_plane == 3